# linse

[![Build Status](https://github.com/lingpy/linse/workflows/tests/badge.svg)](https://github.com/lingpy/linse/actions?query=workflow%3Atests)
[![PyPI version](https://badge.fury.io/py/lingpy.png)](https://badge.fury.io/py/lingpy)

The `linse` package implements functionality to manipulate **lin**guistic **se**quences,
i.e. lists of tokens created by segmenting text.
